@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Geometer Plus <contact@geometerplus.com>
+ * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,9 +25,9 @@
 class FootnoteView : public FBView {
 
 public:
-	FootnoteView(FBReader &reader, shared_ptr<ZLPaintContext> context);
+	FootnoteView(ZLPaintContext &context);
 };
 
-inline FootnoteView::FootnoteView(FBReader &reader, shared_ptr<ZLPaintContext> context) : FBView(reader, context) {}
+inline FootnoteView::FootnoteView(ZLPaintContext &context) : FBView(context) {}
 
 #endif /* __FOOTNOTEVIEW_H__ */
